@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2013-2016 Horde LLC
+ * @copyright 2013-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Cache
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013-2016 Horde LLC
+ * @copyright 2013-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Cache
  */
@@ -100,7 +100,7 @@ class Horde_Cache_Storage_Mongo extends Horde_Cache_Storage_Base
         }
 
         try {
-            $result = $this->_db->findOne($query, array(self::DATA));
+            $result = $this->_db->findOne($query, array(self::DATA => true));
         } catch (MongoException $e) {
             $this->_logger->log($e->getMessage(), 'DEBUG');
             return false;
