@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2016-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -45,12 +45,12 @@ class Horde_Cache_MongoTest extends Horde_Cache_TestBase
             $this->reason = 'MongoDB not available.';
             return;
         }
-        return new Horde_Cache(
-            new Horde_Cache_Storage_Mongo(array(
-                'mongo_db' => $this->mongo,
-                'collection' => 'horde_cache_test'
-            ))
-        );
+        $storage = new Horde_Cache_Storage_Mongo(array(
+            'mongo_db' => $this->mongo,
+            'collection' => 'horde_cache_test'
+        ));
+        //$storage->setLogger(new Horde_Log_Logger(new Horde_Log_Handler_Cli()));
+        return new Horde_Cache($storage);
     }
 
     public function tearDown()
